@@ -26,10 +26,19 @@ class Arger(arger.Arger):
 
 
 class Command(ArgParserAlias):
-    def __init__(self, func: Callable, **kwargs):
+    def __init__(self, func: Callable, threadable=True, capturable=True, **kwargs):
         """Convert the given function to alias and also create a argparser for its parameters"""
         super().__init__()
         self.prog = func.__name__.strip("_").replace("_", "-")
+        if not threadable:
+            from xonsh.tools import unthreadable
+
+            unthreadable(self)
+        if not capturable:
+            from xonsh.tools import uncapturable
+
+            uncapturable(self)
+
         kwargs["func"] = func
         kwargs["prog"] = self.prog
         self.kwargs = kwargs
@@ -42,6 +51,18 @@ class Command(ArgParserAlias):
         cls(func, **kwargs)
         return func
 
+    @classmethod
+    def reg_no_thread(cls, func, **kwargs):
+        """pickle safe way to register alias function that is not threadable"""
+        kwargs.setdefault("threadable", False)
+        return cls.reg(func, **kwargs)
+
+    @classmethod
+    def reg_no_cap(cls, func, **kwargs):
+        """pickle safe way to register alias function that is not capturable"""
+        kwargs.setdefault("capturable", False)
+        return cls.reg(func, **kwargs)
+
     def build(self) -> "Arger":
         return Arger(**self.kwargs)
 
